smartcard.ulist.ulist

# ``smartcard`.`ulist`.`ulist``

class documentation

`class ulist(list):`

Known subclasses: `smartcard.reader.ReaderGroups.innerreadergroups`

View In Hierarchy

ulist ensures that all items are unique and provides an __onadditem__ hook to perform custom action in subclasses.

Method | `__add__` | Undocumented
Method | `__appendother__` | Append other to object.
Method | `__iadd__` | Undocumented
Method | `__init__` | Undocumented
Method | `__onadditem__` | Called for each item added. Override in subclasses for adding custom action.
Method | `__onremoveitem__` | Called for each item removed. Override in subclasses for adding custom action.
Method | `__radd__` | Undocumented
Method | `append` | Undocumented
Method | `insert` | Undocumented
Method | `pop` | Undocumented
Method | `remove` | Undocumented
Method | `__remove_duplicates` | Remove from other items already in list.

def __add__(self, other):

Undocumented

def __appendother__(self, other):

Append other to object.

def __iadd__(self, other):

Undocumented

def __init__(self, initlist=None):
overridden in `smartcard.reader.ReaderGroups.innerreadergroups`

Undocumented

def __onadditem__(self, item):
overridden in `smartcard.reader.ReaderGroups.innerreadergroups`

Called for each item added. Override in subclasses for adding custom action.

def __onremoveitem__(self, item):
overridden in `smartcard.reader.ReaderGroups.innerreadergroups`

Called for each item removed. Override in subclasses for adding custom action.

def __radd__(self, other):

Undocumented

def append(self, item):

Undocumented

def insert(self, i, item):

Undocumented

def pop(self, i=-1):

Undocumented

def remove(self, item):

Undocumented

def __remove_duplicates(self, _other):

Remove from other items already in list.